Index: client/crash_report_database.h |
diff --git a/client/crash_report_database.h b/client/crash_report_database.h |
index 3db2f583b978b4d32fc19c9394eabb805d2964d2..ef55d9d27be85cf1d154f7a2cadb5c975a3819d4 100644 |
--- a/client/crash_report_database.h |
+++ b/client/crash_report_database.h |
@@ -145,7 +145,7 @@ class CrashReportDatabase { |
//! |
//! Callers can then write the crash report using the file handle provided. |
//! The caller does not own this handle, and it must be explicitly closed with |
- //! FinishedWritingCrashReport(). |
+ //! FinishedWritingCrashReport() or ErrorWritingCrashReport(). |
//! |
//! \param[out] report A file handle to which the crash report data should be |
//! written. Only valid if this returns #kNoError. The caller must not |
@@ -157,7 +157,7 @@ class CrashReportDatabase { |
//! \brief Informs the database that a crash report has been written. |
//! |
//! After calling this method, the database is permitted to move and rename |
//! the file at Report::file_path. |
//! |
//! \param[in] report A handle obtained with PrepareNewCrashReport(). The |
//! handle will be invalidated as part of this call. |
@@ -167,6 +167,19 @@ class CrashReportDatabase { |
virtual OperationStatus FinishedWritingCrashReport(NewReport* report, |
UUID* uuid) = 0; |
+ //! \brief Informs the database that an error occurred while attempting to |
+ //! write a crash report, and that any resources associated with it should |
+ //! be cleaned up. |
+ //! |
+ //! After calling this method, the database is permitted to remove the file at |
+ //! NewReport::path. |
+ //! |
+ //! \param[in] report A handle obtained with PrepareNewCrashReport(). The |
+ //! handle will be invalidated as part of this call. |
+ //! |
+ //! \return The operation status code. |
+ virtual OperationStatus ErrorWritingCrashReport(NewReport* report) = 0; |
+ |
//! \brief Returns the crash report record for the unique identifier. |
//! |
//! \param[in] uuid The crash report record unique identifier. |
@@ -157,7 +157,7 @@ class CrashReportDatabase { |
//! |
//! After calling this method, the database is permitted to move and rename |
- //! the file at Report::file_path. |
+ //! the file at NewReport::path. |
//! |
//! \param[in] report A handle obtained with PrepareNewCrashReport(). The |